# attlesnake: Attitude Dynamics in Python

A Python library for handling rigid body attitude dynamics (tailored for spacecraft).

## Installation

Install with pip:

```bash
pip install attlesnake
```
